@@ -1,30 +1,20 @@
 from __future__ import annotations
 
+from typing import TYPE_CHECKING
+
 from edc_constants.constants import COMPLETE, YES
 from edc_randomization.site_randomizers import site_randomizers
 from edc_utils import get_utcnow
-from intecomm_form_validators.utils import (
-    PatientGroupSizeError,
-    PatientNotConsentedError,
-    PatientNotScreenedError,
-    PatientNotStableError,
-    confirm_patient_group_ratio_or_raise,
-    confirm_patient_group_size_or_raise,
-    confirm_patients_stable_and_screened_and_consented_or_raise,
-)
 
-from intecomm_rando.group_identifier import GroupIdentifier
+from .exceptions import GroupAlreadyRandomized, GroupRandomizationError
+from .group_eligibility import assess_group_eligibility
+from .group_identifier import GroupIdentifier
+
+if TYPE_CHECKING:
+    from intecomm_screening.models import PatientGroup
 
 
-class GroupAlreadyRandomized(Exception):
-    pass
-
-
-class GroupRandomizationError(Exception):
-    pass
-
-
-def randomize_group(instance) -> None:
+def randomize_group(instance: PatientGroup) -> None:
     rando = RandomizeGroup(instance)
     rando.randomize_group()
 
@@ -33,7 +23,7 @@ class RandomizeGroup:
 
     min_group_size = 14
 
-    def __init__(self, instance):
+    def __init__(self, instance: PatientGroup):
         self.instance = instance
 
     def randomize_group(self):
@@ -47,39 +37,18 @@ class RandomizeGroup:
                 "Invalid. Expected YES. See `randomize_now`. "
                 f"Got {self.instance.randomize_now}."
             )
+
         if self.instance.status != COMPLETE:
             raise GroupRandomizationError(f"Group is not complete. Got {self.instance}.")
-        self.confirm_patients_stable_and_screened_and_consented_or_raise()
-        self.confirm_patient_group_size_or_raise()
-        self.confirm_patient_group_ratio_or_raise()
+
+        assess_group_eligibility(self.instance, called_by_rando=True)
+
         self.randomize()
+
         return True, get_utcnow(), self.instance.user_modified, self.instance.group_identifier
 
-    def confirm_patients_stable_and_screened_and_consented_or_raise(self):
-        try:
-            confirm_patients_stable_and_screened_and_consented_or_raise(
-                patients=self.instance.patients
-            )
-        except (PatientNotStableError, PatientNotScreenedError, PatientNotConsentedError) as e:
-            raise GroupRandomizationError(e)
-
-    def confirm_patient_group_size_or_raise(self):
-        try:
-            confirm_patient_group_size_or_raise(
-                enforce_group_size_min=self.instance.enforce_group_size_min,
-                patients=self.instance.patients,
-            )
-        except PatientGroupSizeError as e:
-            raise GroupRandomizationError(e)
-
-    def confirm_patient_group_ratio_or_raise(self):
-        confirm_patient_group_ratio_or_raise(
-            patients=self.instance.patients,
-            enforce_ratio=self.instance.enforce_ratio,
-        )
-
     def randomize(self) -> None:
-        identifier_obj = GroupIdentifier(
+        identifier_instance = GroupIdentifier(
             identifier_type="patient_group",
             group_identifier_as_pk=self.instance.group_identifier_as_pk,
             requesting_model=self.instance._meta.label_lower,
@@ -88,12 +57,12 @@ class RandomizeGroup:
         report_datetime = get_utcnow()
         site_randomizers.randomize(
             "default",
-            identifier=identifier_obj.identifier,
+            identifier=identifier_instance.identifier,
             report_datetime=report_datetime,
             site=self.instance.site,
             user=self.instance.user_created,
         )
-        self.instance.group_identifier = identifier_obj.identifier
+        self.instance.group_identifier = identifier_instance.identifier
         self.instance.randomized = True
         self.instance.modified = report_datetime
         self.instance.save(
